@@ -6,7 +6,7 @@ from deepface.commons import distance
 
 def build_model(detector_backend):
 
-    global face_detector_obj, face_detector_label
+    global face_detector_obj
 
     backends = {
         'opencv': OpenCvWrapper.build_model,
@@ -16,16 +16,20 @@ def build_model(detector_backend):
         'retinaface': RetinaFaceWrapper.build_model
     }
 
-    if not "face_detector_obj" in globals() or face_detector_label != detector_backend:
-        face_detector_obj = backends.get(detector_backend)
-        face_detector_label = detector_backend
+    if not "face_detector_obj" in globals():
+        face_detector_obj = {}
 
-        if face_detector_obj:
-            face_detector_obj = face_detector_obj()
+    if not detector_backend in face_detector_obj.keys():
+        face_detector = backends.get(detector_backend)
+
+        if face_detector:
+            face_detector = face_detector()
+            face_detector_obj[detector_backend] = face_detector
+            #print(detector_backend," built")
         else:
             raise ValueError("invalid detector_backend passed - " + detector_backend)
 
-    return face_detector_obj
+    return face_detector_obj[detector_backend]
 
 def detect_face(face_detector, detector_backend, img, align = True):
 
